/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Abound from "../../../index";
export declare namespace Form1099K {
    interface Options {
        environment?: core.Supplier<environments.AboundEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey: core.Supplier<core.BearerToken>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Form1099K {
    protected readonly _options: Form1099K.Options;
    constructor(_options: Form1099K.Options);
    /**
     * Returns a list of 1099-K documents.
     *
     * @param {Abound.Form1099KListRequest} request
     * @param {Form1099K.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099K.list()
     */
    list(request?: Abound.Form1099KListRequest, requestOptions?: Form1099K.RequestOptions): Promise<Abound.Form1099KSchema[]>;
    /**
     * Creates a 1099-K document and subsequently kicks off a TIN Verification, if the name and TIN combo has not been used before.
     *
     * @param {Abound.Form1099KRequest} request
     * @param {Form1099K.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099K.create({
     *         body: {
     *             filingYear: 2024,
     *             payer: {
     *                 name: "Hooli",
     *                 tin: "111111111",
     *                 address: "256 Byron Street",
     *                 address2: "Suite 32",
     *                 city: "Palo Alto",
     *                 state: "CA",
     *                 postalCode: "94306",
     *                 country: "US",
     *                 phoneNumber: "+16501014096"
     *             },
     *             payee: {
     *                 name: "Ada Lovelace",
     *                 tin: "000000000",
     *                 address: "1401 N Shoreline Blvd",
     *                 address2: "Suite 1",
     *                 city: "Mountain View",
     *                 state: "CA",
     *                 postalCode: "94043",
     *                 country: "US"
     *             },
     *             formFields: {
     *                 accountNumber: "A0MCFOfvWWL7AVtwrhiU",
     *                 aggregateGrossAmount: 27987876,
     *                 aggregateGrossAmountCardNotPresent: 2332323,
     *                 federalIncomeTaxWithheld: 0,
     *                 merchantCategoryCode: "4582",
     *                 numberOfPaymentTransactions: 767,
     *                 pseName: "Payment Entity",
     *                 payerClassification: "PSE",
     *                 transactionsReportedClassification: "PAYMENT_CARD",
     *                 psePhoneNumber: "+15555555555",
     *                 grossAmountsByMonth: {
     *                     april: 2332323,
     *                     august: 2332323,
     *                     december: 2332323,
     *                     february: 2332323,
     *                     january: 2332323,
     *                     july: 2332323,
     *                     june: 2332323,
     *                     march: 2332323,
     *                     may: 2332323,
     *                     november: 2332323,
     *                     october: 2332323,
     *                     september: 2332323
     *                 },
     *                 stateTaxInfo: [{
     *                         filingState: "CA",
     *                         stateTaxWithheld: 0
     *                     }]
     *             }
     *         }
     *     })
     */
    create(request: Abound.Form1099KRequest, requestOptions?: Form1099K.RequestOptions): Promise<Abound.Form1099KSchema>;
    /**
     * Mails a 1099-K document.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099KMailingRequest} request
     * @param {Form1099K.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099K.mail("documentId_sampletTtqNfulW8", {
     *         body: {
     *             to: {
     *                 address: "1401 N Shoreline Blvd",
     *                 address2: "Suite 1",
     *                 city: "Mountain View",
     *                 state: "CA",
     *                 postalCode: "94043",
     *                 country: "US",
     *                 name: "Ada Lovelace"
     *             },
     *             from: {
     *                 address: "256 Byron Street",
     *                 address2: "Suite 32",
     *                 city: "Palo Alto",
     *                 state: "CA",
     *                 postalCode: "94306",
     *                 country: "US",
     *                 name: "Hooli"
     *             }
     *         }
     *     })
     */
    mail(documentId: Abound.types.DocumentId, request: Abound.Form1099KMailingRequest, requestOptions?: Form1099K.RequestOptions): Promise<Abound.MailingSchema>;
    /**
     * Files a 1099-K document.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099KFileRequest} request
     * @param {Form1099K.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099K.file("documentId_sampletTtqNfulW8")
     */
    file(documentId: Abound.types.DocumentId, request?: Abound.Form1099KFileRequest, requestOptions?: Form1099K.RequestOptions): Promise<Abound.Form1099KSchema>;
    /**
     * Files a new corrected 1099-K and relates it to the original document. A 1099-K can be corrected only after it has reached the `FILED` status. Automatically handles both one-transaction and two-transaction corrections.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099KCorrectRequest} request
     * @param {Form1099K.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099K.correct("documentId_sampletTtqNfulW8", {
     *         body: {
     *             payee: {
     *                 name: "Ada Lovelace",
     *                 tin: "000000000",
     *                 address: "1401 N Shoreline Blvd",
     *                 address2: "Suite 1",
     *                 city: "Mountain View",
     *                 state: "CA",
     *                 postalCode: "94043",
     *                 country: "US"
     *             },
     *             formFields: {
     *                 accountNumber: "A0MCFOfvWWL7AVtwrhiU",
     *                 aggregateGrossAmount: 25655553,
     *                 aggregateGrossAmountCardNotPresent: 25655553,
     *                 federalIncomeTaxWithheld: 0,
     *                 merchantCategoryCode: "4582",
     *                 numberOfPaymentTransactions: 767,
     *                 pseName: "Payment Entity",
     *                 payerClassification: "PSE",
     *                 transactionsReportedClassification: "PAYMENT_CARD",
     *                 psePhoneNumber: "+15555555555",
     *                 grossAmountsByMonth: {
     *                     april: 2332323,
     *                     august: 2332323,
     *                     december: 2332323,
     *                     february: 2332323,
     *                     january: 0,
     *                     july: 2332323,
     *                     june: 2332323,
     *                     march: 2332323,
     *                     may: 2332323,
     *                     november: 2332323,
     *                     october: 2332323,
     *                     september: 2332323
     *                 },
     *                 stateTaxInfo: [{
     *                         filingState: "CA"
     *                     }]
     *             }
     *         }
     *     })
     */
    correct(documentId: Abound.types.DocumentId, request: Abound.Form1099KCorrectRequest, requestOptions?: Form1099K.RequestOptions): Promise<Abound.Form1099KSchema>;
    /**
     * Files a new voided 1099-K and relates it to the original document. A 1099-K can be voided only after it has reached the `FILED` status.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099KVoidRequest} request
     * @param {Form1099K.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099K.void("documentId_sampletTtqNfulW8")
     */
    void(documentId: Abound.types.DocumentId, request?: Abound.Form1099KVoidRequest, requestOptions?: Form1099K.RequestOptions): Promise<Abound.Form1099KSchema>;
    /**
     * Retrieves the details of an existing 1099-K document.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Form1099K.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099K.retrieve("documentId_sampletTtqNfulW8")
     */
    retrieve(documentId: Abound.types.DocumentId, requestOptions?: Form1099K.RequestOptions): Promise<Abound.Form1099KSchema>;
    /**
     * Deletes a 1099-K document. Once an action (`/file`, `/correct`, `/void`) has been executed on a 1099-K, it cannot be deleted.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Form1099K.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099K.delete("documentId_sampletTtqNfulW8")
     */
    delete(documentId: Abound.types.DocumentId, requestOptions?: Form1099K.RequestOptions): Promise<Abound.types.OkSchema>;
    protected _getAuthorizationHeader(): Promise<string>;
}
