/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Abound from "../../../index";
export declare namespace Form1099Misc {
    interface Options {
        environment?: core.Supplier<environments.AboundEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey: core.Supplier<core.BearerToken>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Form1099Misc {
    protected readonly _options: Form1099Misc.Options;
    constructor(_options: Form1099Misc.Options);
    /**
     * Returns a list of 1099-MISC documents.
     *
     * @param {Abound.Form1099MiscListRequest} request
     * @param {Form1099Misc.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Misc.list()
     */
    list(request?: Abound.Form1099MiscListRequest, requestOptions?: Form1099Misc.RequestOptions): Promise<Abound.Form1099MiscSchema[]>;
    /**
     * Creates a 1099-MISC document and subsequently kicks off a TIN Verification, if the name and TIN combo has not been used before.
     *
     * @param {Abound.Form1099MiscRequest} request
     * @param {Form1099Misc.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Misc.create({
     *         body: {
     *             filingYear: 2024,
     *             payer: {
     *                 name: "Hooli",
     *                 tin: "111111111",
     *                 address: "256 Byron Street",
     *                 address2: "Suite 32",
     *                 city: "Palo Alto",
     *                 state: "CA",
     *                 postalCode: "94306",
     *                 country: "US",
     *                 phoneNumber: "+16501014096"
     *             },
     *             payee: {
     *                 name: "Ada Lovelace",
     *                 tin: "000000000",
     *                 address: "1401 N Shoreline Blvd",
     *                 address2: "Suite 1",
     *                 city: "Mountain View",
     *                 state: "CA",
     *                 postalCode: "94043",
     *                 country: "US"
     *             },
     *             formFields: {
     *                 cropInsuranceProceeds: 97109,
     *                 excessGoldenParachutePayments: 97109,
     *                 federalIncomeTaxWithheld: 0,
     *                 fishPurchasedForResale: 97109,
     *                 fishingBoatProceeds: 97109,
     *                 grossProceedsPaidToAnAttorney: 97109,
     *                 hasDirectSalesOver5000: false,
     *                 hasFatcaFilingRequirement: true,
     *                 medicalAndHealthCarePayments: 97109,
     *                 nonqualifiedDeferredCompensation: 97109,
     *                 substitutePaymentsInLieuOfDividendsOrInterest: 97109,
     *                 otherIncome: 97109,
     *                 rents: 97109,
     *                 royalties: 97109,
     *                 section409ADeferrals: 97109,
     *                 accountNumber: "A00AskD1ZTO4YB8oBHav",
     *                 stateTaxInfo: [{
     *                         filingState: "CA",
     *                         stateIncome: 345543,
     *                         stateTaxWithheld: 0
     *                     }]
     *             }
     *         }
     *     })
     */
    create(request: Abound.Form1099MiscRequest, requestOptions?: Form1099Misc.RequestOptions): Promise<Abound.Form1099MiscSchema>;
    /**
     * Mails a 1099-MISC document.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099MiscMailingRequest} request
     * @param {Form1099Misc.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Misc.mail("documentId_sampleGNPOKNmIgF", {
     *         body: {
     *             to: {
     *                 address: "1401 N Shoreline Blvd",
     *                 address2: "Suite 1",
     *                 city: "Mountain View",
     *                 state: "CA",
     *                 postalCode: "94043",
     *                 country: "US",
     *                 name: "Ada Lovelace"
     *             },
     *             from: {
     *                 address: "256 Byron Street",
     *                 address2: "Suite 32",
     *                 city: "Palo Alto",
     *                 state: "CA",
     *                 postalCode: "94306",
     *                 country: "US",
     *                 name: "Hooli"
     *             }
     *         }
     *     })
     */
    mail(documentId: Abound.types.DocumentId, request: Abound.Form1099MiscMailingRequest, requestOptions?: Form1099Misc.RequestOptions): Promise<Abound.MailingSchema>;
    /**
     * Files a 1099-MISC document.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099MiscFileRequest} request
     * @param {Form1099Misc.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Misc.file("documentId_sampleGNPOKNmIgF")
     */
    file(documentId: Abound.types.DocumentId, request?: Abound.Form1099MiscFileRequest, requestOptions?: Form1099Misc.RequestOptions): Promise<Abound.Form1099MiscSchema>;
    /**
     * Files a new corrected 1099-MISC and relates it to the original document. A 1099-MISC can be corrected only after it has reached the `FILED` status. Automatically handles both one-transaction and two-transaction corrections.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099MiscCorrectRequest} request
     * @param {Form1099Misc.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Misc.correct("documentId_sampleGNPOKNmIgF", {
     *         body: {
     *             payee: {
     *                 name: "Ada Lovelace",
     *                 tin: "000000000",
     *                 address: "1401 N Shoreline Blvd",
     *                 address2: "Suite 1",
     *                 city: "Mountain View",
     *                 state: "CA",
     *                 postalCode: "94043",
     *                 country: "US"
     *             },
     *             formFields: {
     *                 cropInsuranceProceeds: 97109,
     *                 excessGoldenParachutePayments: 97109,
     *                 federalIncomeTaxWithheld: 0,
     *                 fishPurchasedForResale: 97109,
     *                 fishingBoatProceeds: 97109,
     *                 grossProceedsPaidToAnAttorney: 97109,
     *                 hasDirectSalesOver5000: false,
     *                 hasFatcaFilingRequirement: true,
     *                 medicalAndHealthCarePayments: 97109,
     *                 nonqualifiedDeferredCompensation: 97109,
     *                 substitutePaymentsInLieuOfDividendsOrInterest: 97109,
     *                 otherIncome: 97109,
     *                 rents: 10000,
     *                 royalties: 97109,
     *                 section409ADeferrals: 97109,
     *                 accountNumber: "A00AskD1ZTO4YB8oBHav",
     *                 stateTaxInfo: [{
     *                         filingState: "CA",
     *                         stateIncome: 258434
     *                     }]
     *             }
     *         }
     *     })
     */
    correct(documentId: Abound.types.DocumentId, request: Abound.Form1099MiscCorrectRequest, requestOptions?: Form1099Misc.RequestOptions): Promise<Abound.Form1099MiscSchema>;
    /**
     * Files a new voided 1099-MISC and relates it to the original document. A 1099-MISC can be voided only after it has reached the `FILED` status.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099MiscVoidRequest} request
     * @param {Form1099Misc.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Misc.void("documentId_sampleGNPOKNmIgF")
     */
    void(documentId: Abound.types.DocumentId, request?: Abound.Form1099MiscVoidRequest, requestOptions?: Form1099Misc.RequestOptions): Promise<Abound.Form1099MiscSchema>;
    /**
     * Retrieves the details of an existing 1099-MISC document.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Form1099Misc.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Misc.retrieve("documentId_sampleGNPOKNmIgF")
     */
    retrieve(documentId: Abound.types.DocumentId, requestOptions?: Form1099Misc.RequestOptions): Promise<Abound.Form1099MiscSchema>;
    /**
     * Deletes a 1099-MISC document. Once an action (`/file`, `/correct`, `/void`) has been executed on a 1099-MISC, it cannot be deleted.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Form1099Misc.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Misc.delete("documentId_sampleGNPOKNmIgF")
     */
    delete(documentId: Abound.types.DocumentId, requestOptions?: Form1099Misc.RequestOptions): Promise<Abound.types.OkSchema>;
    protected _getAuthorizationHeader(): Promise<string>;
}
