/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Abound from "../../../index";
export declare namespace TinVerifications {
    interface Options {
        environment?: core.Supplier<environments.AboundEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey: core.Supplier<core.BearerToken>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class TinVerifications {
    protected readonly _options: TinVerifications.Options;
    constructor(_options: TinVerifications.Options);
    /**
     * Returns a list of TIN Verifications. Up to 100 TIN Verifications are returned per request.
     *
     * @param {Abound.TinVerificationsListRequest} request
     * @param {TinVerifications.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.tinVerifications.list()
     */
    list(request?: Abound.TinVerificationsListRequest, requestOptions?: TinVerifications.RequestOptions): Promise<Abound.TinVerificationSchema[]>;
    /**
     * Creates an asynchronous TIN Verification.
     *
     * @param {Abound.TinVerificationRequest} request
     * @param {TinVerifications.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.tinVerifications.create({
     *         body: {
     *             name: "Ada Lovelace",
     *             tin: "000000000"
     *         }
     *     })
     */
    create(request: Abound.TinVerificationRequest, requestOptions?: TinVerifications.RequestOptions): Promise<Abound.TinVerificationSchema>;
    /**
     * Retrieves the details of an existing TIN Verification.
     *
     * @param {Abound.types.TinVerificationId} tinVerificationId
     * @param {TinVerifications.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.tinVerifications.retrieve("tinVerificationId_sample41SD71AV8f")
     */
    retrieve(tinVerificationId: Abound.types.TinVerificationId, requestOptions?: TinVerifications.RequestOptions): Promise<Abound.TinVerificationSchema>;
    protected _getAuthorizationHeader(): Promise<string>;
}
