/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Abound from "../../../index";
export declare namespace Form1099Int {
    interface Options {
        environment?: core.Supplier<environments.AboundEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey: core.Supplier<core.BearerToken>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Form1099Int {
    protected readonly _options: Form1099Int.Options;
    constructor(_options: Form1099Int.Options);
    /**
     * Returns a list of 1099-INT documents.
     *
     * @param {Abound.Form1099IntListRequest} request
     * @param {Form1099Int.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Int.list()
     */
    list(request?: Abound.Form1099IntListRequest, requestOptions?: Form1099Int.RequestOptions): Promise<Abound.Form1099IntSchema[]>;
    /**
     * Creates a 1099-INT document and subsequently kicks off a TIN Verification, if the name and TIN combo has not been used before.
     *
     * @param {Abound.Form1099IntRequest} request
     * @param {Form1099Int.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Int.create({
     *         body: {
     *             filingYear: 2024,
     *             payer: {
     *                 name: "Hooli",
     *                 tin: "111111111",
     *                 address: "256 Byron Street",
     *                 address2: "Suite 32",
     *                 city: "Palo Alto",
     *                 state: "CA",
     *                 postalCode: "94306",
     *                 country: "US",
     *                 phoneNumber: "+16501014096"
     *             },
     *             payee: {
     *                 name: "Ada Lovelace",
     *                 tin: "000000000",
     *                 address: "1401 N Shoreline Blvd",
     *                 address2: "Suite 1",
     *                 city: "Mountain View",
     *                 state: "CA",
     *                 postalCode: "94043",
     *                 country: "US"
     *             },
     *             formFields: {
     *                 bondPremium: 19423,
     *                 bondPremiumTaxExemptBond: 19423,
     *                 bondPremiumTreasury: 19423,
     *                 earlyWithdrawalPenalty: 23223,
     *                 foreignTaxPaid: 19423,
     *                 foreignTaxPaidCountry: "FR",
     *                 hasFatcaFilingRequirement: true,
     *                 interestIncome: 83232,
     *                 investmentExpenses: 19423,
     *                 marketDiscount: 19423,
     *                 payersRoutingNumber: "054000030",
     *                 specifiedPrivateActivityBondInterest: 19423,
     *                 taxExemptInterest: 19423,
     *                 usSavingsBondsInterest: 19423,
     *                 federalIncomeTaxWithheld: 0,
     *                 accountNumber: "A006SVmcrieFAbm3gsaV",
     *                 stateTaxInfo: [{
     *                         filingState: "CA",
     *                         stateTaxWithheld: 0
     *                     }]
     *             }
     *         }
     *     })
     */
    create(request: Abound.Form1099IntRequest, requestOptions?: Form1099Int.RequestOptions): Promise<Abound.Form1099IntSchema>;
    /**
     * Mails a 1099-INT document.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099IntMailingRequest} request
     * @param {Form1099Int.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Int.mail("documentId_samplepWpJ9Snlzb", {
     *         body: {
     *             to: {
     *                 address: "1401 N Shoreline Blvd",
     *                 address2: "Suite 1",
     *                 city: "Mountain View",
     *                 state: "CA",
     *                 postalCode: "94043",
     *                 country: "US",
     *                 name: "Ada Lovelace"
     *             },
     *             from: {
     *                 address: "256 Byron Street",
     *                 address2: "Suite 32",
     *                 city: "Palo Alto",
     *                 state: "CA",
     *                 postalCode: "94306",
     *                 country: "US",
     *                 name: "Hooli"
     *             }
     *         }
     *     })
     */
    mail(documentId: Abound.types.DocumentId, request: Abound.Form1099IntMailingRequest, requestOptions?: Form1099Int.RequestOptions): Promise<Abound.MailingSchema>;
    /**
     * Files a 1099-INT document.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099IntFileRequest} request
     * @param {Form1099Int.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Int.file("documentId_samplepWpJ9Snlzb")
     */
    file(documentId: Abound.types.DocumentId, request?: Abound.Form1099IntFileRequest, requestOptions?: Form1099Int.RequestOptions): Promise<Abound.Form1099IntSchema>;
    /**
     * Files a new corrected 1099-INT and relates it to the original document. A 1099-INT can be corrected only after it has reached the `FILED` status. Automatically handles both one-transaction and two-transaction corrections.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099IntCorrectRequest} request
     * @param {Form1099Int.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Int.correct("documentId_samplepWpJ9Snlzb", {
     *         body: {
     *             payee: {
     *                 name: "Ada Lovelace",
     *                 tin: "000000000",
     *                 address: "1401 N Shoreline Blvd",
     *                 address2: "Suite 1",
     *                 city: "Mountain View",
     *                 state: "CA",
     *                 postalCode: "94043",
     *                 country: "US"
     *             },
     *             formFields: {
     *                 bondPremium: 19423,
     *                 bondPremiumTaxExemptBond: 19423,
     *                 bondPremiumTreasury: 19423,
     *                 earlyWithdrawalPenalty: 23223,
     *                 foreignTaxPaid: 19423,
     *                 foreignTaxPaidCountry: "FR",
     *                 hasFatcaFilingRequirement: true,
     *                 interestIncome: 10000,
     *                 investmentExpenses: 19423,
     *                 marketDiscount: 19423,
     *                 payersRoutingNumber: "054000030",
     *                 specifiedPrivateActivityBondInterest: 19423,
     *                 taxExemptInterest: 19423,
     *                 usSavingsBondsInterest: 19423,
     *                 federalIncomeTaxWithheld: 0,
     *                 accountNumber: "A006SVmcrieFAbm3gsaV",
     *                 stateTaxInfo: [{
     *                         filingState: "CA"
     *                     }]
     *             }
     *         }
     *     })
     */
    correct(documentId: Abound.types.DocumentId, request: Abound.Form1099IntCorrectRequest, requestOptions?: Form1099Int.RequestOptions): Promise<Abound.Form1099IntSchema>;
    /**
     * Files a new voided 1099-INT and relates it to the original document. A 1099-INT can be voided only after it has reached the `FILED` status.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099IntVoidRequest} request
     * @param {Form1099Int.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Int.void("documentId_samplepWpJ9Snlzb")
     */
    void(documentId: Abound.types.DocumentId, request?: Abound.Form1099IntVoidRequest, requestOptions?: Form1099Int.RequestOptions): Promise<Abound.Form1099IntSchema>;
    /**
     * Retrieves the details of an existing 1099-INT document.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Form1099Int.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Int.retrieve("documentId_samplepWpJ9Snlzb")
     */
    retrieve(documentId: Abound.types.DocumentId, requestOptions?: Form1099Int.RequestOptions): Promise<Abound.Form1099IntSchema>;
    /**
     * Deletes a 1099-INT document. Once an action (`/file`, `/correct`, `/void`) has been executed on a 1099-INT, it cannot be deleted.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Form1099Int.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Int.delete("documentId_samplepWpJ9Snlzb")
     */
    delete(documentId: Abound.types.DocumentId, requestOptions?: Form1099Int.RequestOptions): Promise<Abound.types.OkSchema>;
    protected _getAuthorizationHeader(): Promise<string>;
}
