/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Abound from "../../../index";
export declare namespace Form1099Nec {
    interface Options {
        environment?: core.Supplier<environments.AboundEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey: core.Supplier<core.BearerToken>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Form1099Nec {
    protected readonly _options: Form1099Nec.Options;
    constructor(_options: Form1099Nec.Options);
    /**
     * Returns a list of 1099-NEC documents.
     *
     * @param {Abound.Form1099NecListRequest} request
     * @param {Form1099Nec.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Nec.list()
     */
    list(request?: Abound.Form1099NecListRequest, requestOptions?: Form1099Nec.RequestOptions): Promise<Abound.Form1099NecSchema[]>;
    /**
     * Creates a 1099-NEC document and subsequently kicks off a TIN Verification, if the name and TIN combo has not been used before.
     *
     * @param {Abound.Form1099NecRequest} request
     * @param {Form1099Nec.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Nec.create({
     *         body: {
     *             filingYear: 2024,
     *             payer: {
     *                 name: "Hooli",
     *                 tin: "111111111",
     *                 address: "256 Byron Street",
     *                 address2: "Suite 32",
     *                 city: "Palo Alto",
     *                 state: "CA",
     *                 postalCode: "94306",
     *                 country: "US",
     *                 phoneNumber: "+16501014096"
     *             },
     *             payee: {
     *                 name: "Ada Lovelace",
     *                 tin: "000000000",
     *                 address: "1401 N Shoreline Blvd",
     *                 address2: "Suite 1",
     *                 city: "Mountain View",
     *                 state: "CA",
     *                 postalCode: "94043",
     *                 country: "US"
     *             },
     *             formFields: {
     *                 nonemployeeCompensation: 23423,
     *                 hasDirectSalesOver5000: false,
     *                 federalIncomeTaxWithheld: 0,
     *                 accountNumber: "A0NEqtav7n0sBGoq88w0",
     *                 stateTaxInfo: [{
     *                         filingState: "CA",
     *                         stateIncome: 23423,
     *                         stateTaxWithheld: 0
     *                     }]
     *             }
     *         }
     *     })
     */
    create(request: Abound.Form1099NecRequest, requestOptions?: Form1099Nec.RequestOptions): Promise<Abound.Form1099NecSchema>;
    /**
     * Mails a 1099-NEC document.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099NecMailingRequest} request
     * @param {Form1099Nec.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Nec.mail("documentId_samplegU0eR8oc8a", {
     *         body: {
     *             to: {
     *                 address: "1401 N Shoreline Blvd",
     *                 address2: "Suite 1",
     *                 city: "Mountain View",
     *                 state: "CA",
     *                 postalCode: "94043",
     *                 country: "US",
     *                 name: "Ada Lovelace"
     *             },
     *             from: {
     *                 address: "256 Byron Street",
     *                 address2: "Suite 32",
     *                 city: "Palo Alto",
     *                 state: "CA",
     *                 postalCode: "94306",
     *                 country: "US",
     *                 name: "Hooli"
     *             }
     *         }
     *     })
     */
    mail(documentId: Abound.types.DocumentId, request: Abound.Form1099NecMailingRequest, requestOptions?: Form1099Nec.RequestOptions): Promise<Abound.MailingSchema>;
    /**
     * Files a 1099-NEC document.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099NecFileRequest} request
     * @param {Form1099Nec.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Nec.file("documentId_samplegU0eR8oc8a")
     */
    file(documentId: Abound.types.DocumentId, request?: Abound.Form1099NecFileRequest, requestOptions?: Form1099Nec.RequestOptions): Promise<Abound.Form1099NecSchema>;
    /**
     * Files a new corrected 1099-NEC and relates it to the original document. A 1099-NEC can be corrected only after it has reached the `FILED` status. Automatically handles both one-transaction and two-transaction corrections.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099NecCorrectRequest} request
     * @param {Form1099Nec.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Nec.correct("documentId_samplegU0eR8oc8a", {
     *         body: {
     *             payee: {
     *                 name: "Ada Lovelace",
     *                 tin: "000000000",
     *                 address: "1401 N Shoreline Blvd",
     *                 address2: "Suite 1",
     *                 city: "Mountain View",
     *                 state: "CA",
     *                 postalCode: "94043",
     *                 country: "US"
     *             },
     *             formFields: {
     *                 nonemployeeCompensation: 10000,
     *                 accountNumber: "A0NEqtav7n0sBGoq88w0",
     *                 stateTaxInfo: [{
     *                         filingState: "CA",
     *                         stateIncome: 10000
     *                     }]
     *             }
     *         }
     *     })
     */
    correct(documentId: Abound.types.DocumentId, request: Abound.Form1099NecCorrectRequest, requestOptions?: Form1099Nec.RequestOptions): Promise<Abound.Form1099NecSchema>;
    /**
     * Files a new voided 1099-NEC and relates it to the original document. A 1099-NEC can be voided only after it has reached the `FILED` status.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Abound.Form1099NecVoidRequest} request
     * @param {Form1099Nec.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Nec.void("documentId_samplegU0eR8oc8a")
     */
    void(documentId: Abound.types.DocumentId, request?: Abound.Form1099NecVoidRequest, requestOptions?: Form1099Nec.RequestOptions): Promise<Abound.Form1099NecSchema>;
    /**
     * Retrieves the details of an existing 1099-NEC document.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Form1099Nec.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Nec.retrieve("documentId_samplegU0eR8oc8a")
     */
    retrieve(documentId: Abound.types.DocumentId, requestOptions?: Form1099Nec.RequestOptions): Promise<Abound.Form1099NecSchema>;
    /**
     * Deletes a 1099-NEC document. Once an action (`/file`, `/correct`, `/void`) has been executed on a 1099-NEC, it cannot be deleted.
     *
     * @param {Abound.types.DocumentId} documentId
     * @param {Form1099Nec.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.form1099Nec.delete("documentId_samplegU0eR8oc8a")
     */
    delete(documentId: Abound.types.DocumentId, requestOptions?: Form1099Nec.RequestOptions): Promise<Abound.types.OkSchema>;
    protected _getAuthorizationHeader(): Promise<string>;
}
