/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Abound from "../../../index";
export declare namespace Users {
    interface Options {
        environment?: core.Supplier<environments.AboundEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey: core.Supplier<core.BearerToken>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Users {
    protected readonly _options: Users.Options;
    constructor(_options: Users.Options);
    /**
     * Returns a list of users. Up to 100 users are returned per request.
     *
     * @param {Abound.UsersListRequest} request
     * @param {Users.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.users.list()
     */
    list(request?: Abound.UsersListRequest, requestOptions?: Users.RequestOptions): Promise<Abound.UserSchema[]>;
    /**
     * Creates a user for a single end-user of your application.
     *
     * @param {Abound.UsersCreateRequest} request
     * @param {Users.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.ConflictErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.users.create({
     *         body: {
     *             foreignId: "my-foreign-id"
     *         }
     *     })
     */
    create(request: Abound.UsersCreateRequest, requestOptions?: Users.RequestOptions): Promise<Abound.UserSchema>;
    /**
     * Retrieves the details of an existing user.
     *
     * @param {Abound.types.UserId} userId
     * @param {Users.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.InternalServerErrorSchema}
     *
     * @example
     *     await client.users.retrieve("userId_sampleXGMFnhOpeR")
     */
    retrieve(userId: Abound.types.UserId, requestOptions?: Users.RequestOptions): Promise<Abound.UserSchema>;
    /**
     * Updates an existing user. Any body parameters not provided will be removed.
     *
     * @param {Abound.types.UserId} userId
     * @param {Abound.UserRequestSchema} request
     * @param {Users.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Abound.types.BadRequestErrorSchema}
     * @throws {@link Abound.types.UnauthorizedErrorSchema}
     * @throws {@link Abound.types.NotFoundErrorSchema}
     * @throws {@link Abound.types.ConflictErrorSchema}
     *
     * @example
     *     await client.users.update("userId_sampleXGMFnhOpeR", {
     *         foreignId: "my-foreign-id"
     *     })
     */
    update(userId: Abound.types.UserId, request: Abound.UserRequestSchema, requestOptions?: Users.RequestOptions): Promise<Abound.UserSchema>;
    protected _getAuthorizationHeader(): Promise<string>;
}
